@@ -9,25 +9,14 @@
  * @license   http://opensource.org/licenses/bsd-license.php The BSD License
  */
 
-define('MOONY_VERSION', '0.11.2');
+define('MOONY_VERSION', '0.12.1');
 define('MOONY_ROOT_DIR', dirname(__FILE__));
 
-define('MOONY_TEMPLATE_DIR_KEY', 'moony_template_dir');
+define('MOONY_ACTION_KEY', 'moony_action');
+define('MOONY_VALIDATOR_KEY', 'moony_validator');
 define('MOONY_TOKEN_KEY', 'moony_token');
-define('MOONY_HAS_ERROR_KEY', 'moony_has_error');
-define('MOONY_ERROR_MESSAGES_KEY', 'moony_error_messages');
 
-require_once MOONY_ROOT_DIR . '/Moony/Action.php';
-require_once MOONY_ROOT_DIR . '/Moony/Converter.php';
-require_once MOONY_ROOT_DIR . '/Moony/Flash.php';
-require_once MOONY_ROOT_DIR . '/Moony/Registry.php';
-require_once MOONY_ROOT_DIR . '/Moony/Request.php';
-require_once MOONY_ROOT_DIR . '/Moony/Router.php';
-require_once MOONY_ROOT_DIR . '/Moony/Session.php';
-require_once MOONY_ROOT_DIR . '/Moony/Template.php';
-require_once MOONY_ROOT_DIR . '/Moony/Validator.php';
-require_once MOONY_ROOT_DIR . '/Moony/Template/Php.php';
-require_once MOONY_ROOT_DIR . '/Moony/Template/Smarty.php';
+require_once MOONY_ROOT_DIR . '/Moony/Processor.php';
 
 /**
  * Moonyのフロントエンドクラスです。
@@ -81,16 +70,10 @@ class Moony
     var $default_redirect_url;
 
     /**
-     * テンプレートエンジンとしてSmartyを使うかどうか
-     * @var boolean
+     * セッションを自動的に開始するかどうか
+     * @var bool
      */
-    var $use_smarty = false;
-
-    /**
-     * Smartyに設定するプロパティの連想配列
-     * @var array
-     */
-    var $smarty_properties;
+    var $session_auto_start = true;
 
     /**
      * 実行するアクションを決定、処理を開始します。
@@ -99,8 +82,12 @@ class Moony
      */
     function start()
     {
-        $router =& new Moony_Router();
-        $router->route($this);
+        if (is_null($this->internal_encoding)) {
+            // 内部エンコーディング
+            $this->internal_encoding = mb_internal_encoding();
+        }
+        $processor =& new Moony_Processor();
+        $processor->process($this);
     }
 
     /**
@@ -190,17 +177,16 @@ class Moony
     }
 
     /**
-     * テンプレートエンジンとしてSmartyを使用することにします。
-     * $propertiesの個々の要素ははSmartyのプロパティとして設定されます。
-     * （例: array('compile_dir' => 'templates_c')）
+     * セッションを自動的に開始するかどうかを設定します。
+     * 初期設定値は「true」で、変更しない限り
+     * 自動的にセッションが開始されます。
      *
      * @access public
-     * @param array $properties Smartyに設定するプロパティの連想配列
+     * @param bool $session_auto_start セッションを自動で開始するかどうか
      */
-    function useSmarty($properties)
+    function setSessionAutoStart($session_auto_start)
     {
-        $this->use_smarty = true;
-        $this->smarty_properties = $properties;
+        $this->session_auto_start = (bool) $session_auto_start;
     }
 }
 ?>
