@@ -26,7 +26,7 @@ class Moony_Validator
 
     /**
      * エラーの有無
-     * @var boolean
+     * @var bool
      */
     var $_has_error = false;
 
@@ -50,6 +50,8 @@ class Moony_Validator
 
     /**
      * エラーを追加登録します。
+     * validateで始まるメソッドを実行した場合、
+     * 検証エラー時に呼び出されます。
      *
      * @access public
      * @param string $message エラーメッセージ
@@ -60,16 +62,13 @@ class Moony_Validator
         if (!is_null($message)) {
             $this->_error_messages[] = $message;
         }
-        // エラー情報を保管
-        Moony_Registry::set(MOONY_HAS_ERROR_KEY, true);
-        Moony_Registry::set(MOONY_ERROR_MESSAGES_KEY, $this->_error_messages);
     }
 
     /**
      * エラーの存在有無を調べます。
      *
      * @access public
-     * @return boolean エラーの存在有無
+     * @return bool エラーの存在有無
      */
     function hasError()
     {
@@ -77,10 +76,10 @@ class Moony_Validator
     }
 
     /**
-     * 全てのエラーメッセージの配列を取得します。
+     * 全てのエラーメッセージを取得します。
      *
      * @access public
-     * @return array 全てのエラーメッセージの配列
+     * @return array エラーメッセージの配列
      */
     function getErrorMessages()
     {
@@ -93,7 +92,7 @@ class Moony_Validator
      * @access public
      * @param string|array $var 検証対象の値
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateRequired($var, $message = null)
     {
@@ -120,8 +119,8 @@ class Moony_Validator
      * @param string|array $var 検証対象の値
      * @param string $pattern 正規表現パターン
      * @param string $message エラーメッセージ
-     * @param boolean $mb mb_ereg関数を使用するかどうか
-     * @return boolean エラーがなければtrue
+     * @param bool $mb mb_ereg関数を使用するかどうか
+     * @return bool エラーがなければtrue
      */
     function validatePattern($var, $pattern, $message = null, $mb = false)
     {
@@ -153,12 +152,12 @@ class Moony_Validator
      * $varがnullの場合、無条件にエラーなしとみなします。
      *
      * @param string|array $var 検証対象の値
-     * @param integer $min 許容される最小長
-     * @param integer $max 許容される最大長
+     * @param int $min 許容される最小長
+     * @param int $max 許容される最大長
      * @param string $message エラーメッセージ
-     * @param boolean $inclusive 境界値を許容するかどうか
-     * @param boolean $mb mb_strlen関数を使用するかどうか
-     * @return boolean エラーがなければtrue
+     * @param bool $inclusive 境界値を許容するかどうか
+     * @param bool $mb mb_strlen関数を使用するかどうか
+     * @return bool エラーがなければtrue
      */
     function validateLength($var, $min, $max,
         $message = null, $inclusive = true, $mb = false)
@@ -187,11 +186,11 @@ class Moony_Validator
      * $varがnullの場合、無条件にエラーなしとみなします。
      *
      * @param string|array $var 検証対象の値
-     * @param integer $min 許容される最小値
-     * @param integer $max 許容される最大値
+     * @param int $min 許容される最小値
+     * @param int $max 許容される最大値
      * @param string $message エラーメッセージ
-     * @param boolean $inclusive 境界値を許容するかどうか
-     * @return boolean エラーがなければtrue
+     * @param bool $inclusive 境界値を許容するかどうか
+     * @return bool エラーがなければtrue
      */
     function validateRange(
         $var, $min, $max, $message = null, $inclusive = true)
@@ -220,7 +219,7 @@ class Moony_Validator
      *
      * @param string|array $var 検証対象の値
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateAlpha($var, $message = null)
     {
@@ -234,7 +233,7 @@ class Moony_Validator
      *
      * @param string|array $var 検証対象の値
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateAlnum($var, $message = null)
     {
@@ -248,7 +247,7 @@ class Moony_Validator
      *
      * @param string|array $var 検証対象の値
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateDigit($var, $message = null)
     {
@@ -262,7 +261,7 @@ class Moony_Validator
      *
      * @param string|array $var 検証対象の値
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateNumeric($var, $message = null)
     {
@@ -275,7 +274,7 @@ class Moony_Validator
      *
      * @param string|array $var 検証対象の値
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateHiragana($var, $message = null)
     {
@@ -295,7 +294,7 @@ class Moony_Validator
      *
      * @param string|array $var 検証対象の値
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateKatakana($var, $message = null)
     {
@@ -309,16 +308,44 @@ class Moony_Validator
             '/^(\xe3(\x82[\xa1-\xbf]|\x83[\x80-\xb6]|\x83\xbc))*$/', $message);
     }
 
+    /**
+     * Eメールのアドレスかどうかの検証を行います。
+     * $varがnullの場合、無条件にエラーなしとみなします。
+     *
+     * @param string|array $var 検証対象の値
+     * @param string $message エラーメッセージ
+     * @return bool エラーがなければtrue
+     */
+    function validateEmail($var, $message = null)
+    {
+        return $this->validatePattern($var,
+            '/^([a-z0-9\+_\-]+)(\.[a-z0-9\+_\-]+)*@([a-z0-9\-]+\.)+[a-z]{2,6}$/ix', $messsage);
+    }
+
+    /**
+     * URLかどうかの検証を行います。
+     * $varがnullの場合、無条件にエラーなしとみなします。
+     *
+     * @param string|array $var 検証対象の値
+     * @param string $message エラーメッセージ
+     * @return bool エラーがなければtrue
+     */
+    function validateUrl($var, $message = null)
+    {
+        return $this->validatePattern($var,
+            '/^https?:\/\/[-_.!~*\'()a-zA-Z0-9;\/?:\@&=+\$,%#]+$/', $message);
+    }
+
     /**
      * ユーザ関数を用いた検証を行います。
      * $callbackは引数として個々の入力値をとり、
-     * 検証結果としてboolean値を返す必要があります。
+     * 検証結果としてbool値を返す必要があります。
      * $varがnullの場合、無条件にエラーなしとみなします。
      *
      * @param string|array $var 検証対象の値
      * @param callback $callback 検証用のコールバック関数
      * @param string $message エラーメッセージ
-     * @return boolean エラーがなければtrue
+     * @return bool エラーがなければtrue
      */
     function validateUserFunc($var, $callback, $message = null)
     {
