@@ -18,16 +18,16 @@ if (file_exists($moony_path)) {
     // installed with PEAR
     require_once 'Moony.php';
 }
+require_once MOONY_ROOT_DIR . '/Moony/Converter.php';
+require_once MOONY_ROOT_DIR . '/Moony/Request.php';
+require_once MOONY_ROOT_DIR . '/Moony/Validator.php';
 
 // grouping
 $test =& new GroupTest('All tests');
-$current_dir = dirname(__FILE__);
 
 // add test files
 $test->addTestFile(MOONY_TEST_DIR . '/MoonyTest.php');
 $test->addTestFile(MOONY_TEST_DIR . '/Moony/ConverterTest.php');
-$test->addTestFile(MOONY_TEST_DIR . '/Moony/FlashTest.php');
-$test->addTestFile(MOONY_TEST_DIR . '/Moony/RegistryTest.php');
 $test->addTestFile(MOONY_TEST_DIR . '/Moony/RequestTest.php');
 $test->addTestFile(MOONY_TEST_DIR . '/Moony/ValidatorTest.php');
 
